Crate launch

Crate launch 

Re-exports

pub use discovery::discover;
pub use discovery::generate;
pub use discovery::walk_local;
pub use error::LaunchError;
pub use fs::DirEntry;
pub use fs::FileSystem;
pub use fs::LocalFs;
pub use fs::MemoryFs;
pub use fs::RootedFs;
pub use signal::Signal;
pub use signal::SignalOutput;
pub use types::*;

Modules

discovery
error
fs
signal
signals
types

Functions

discover_local
Discover services in a directory using the default signal set and local filesystem. Uses gitignore-aware walking to skip files the project itself ignores.
discover_with_fs
Discover using a custom filesystem and signal set. For testing.