pub struct RootedFs { /* private fields */ }Expand description
Wraps LocalFs to root all relative paths to a base directory. Solves the CWD mismatch: walk_local strips paths to relative, but generate needs to read files relative to the scanned root, not CWD.
Implementations